# 通用右键菜单组件


## 介绍
> 通用的可配置化右键菜单

- 灵活性：支持配置菜单内容
- 容量大：支持二级、三级等多级菜单
- 支持禁用、隐藏等功能
- 自由度高：由于本菜单仅提供UI渲染和事件传递功能，点击菜单项触发的行为由用户控制


![image.png](https://p1-juejin.byteimg.com/tos-cn-i-k3u1fbpfcp/603c8cb4b8a740028f239146e0e15f28~tplv-k3u1fbpfcp-watermark.image?)


## 使用方法

- 父级元素设置`position: relative;`或者absolute这样可以让右键菜单定位；

```ts
import { ContextMenu, IMenuItem } from '@fes/ui-common';

// 菜单配置数据
const menuList: IMenuItem[] = [
  {
    text: '复制',
    key: 'copy',
    shortcutKey: `${cmd}+C`,
    // 动态判断是否禁用
    disable: (ctx) => ctx.event.target?.getAttribute('id') === 'button',
  },
  {
    text: '粘贴',
    key: 'paste',
    shortcutKey: `${cmd}+V`,
  },
  {
    text: '对齐',
    key: 'align',
    children: [
      {
        text: '水平垂直居中',
        key: 'horizontalVerticalAlign',
      },
      {
        text: '水平居中',
        key: 'horizontalAlign',
      },
    ],
 },
];

export () => {
  const containerDomRef = React.useRef();
  // 菜单点击触发
  const handleMenuTrigger = (menu: IMenuItem) => {
      console.log(menu); // { text: '粘贴', key: 'paste', shortcutKey: '⌘+V' }
      // 这里处理触发菜单后的逻辑....

  };
  return (
    <div ref={containerDomRef} style={{
      position: 'relative',
      width: 800,
      height: 600,
      margin: '0 auto',
    }}>
      <ContextMenu
        getContainerDom={() => containerDomRef.current}
        menuList={menuList}
        onTrigger={handleMenuTrigger}
      />
    </div>
  );
};
```


## 类型

```ts
// 菜单项配置
interface IMenuItem {
  text: string; // 显示的文本
  key: string;  // 唯一key
  disable?: boolean;  // 禁用
  shortcutKey?: React.ReactNode; // 快捷键
  children?: IMenuItem[]; // 有二级扩展菜单
}
```
